@@ -10,8 +10,7 @@ import unidist.core.backends.mpi.core.common as common
 import unidist.core.backends.mpi.core.communication as communication
 from unidist.core.backends.mpi.core.async_operations import AsyncOperations
 from unidist.core.backends.mpi.core.serialization import SimpleDataSerializer
-from unidist.core.backends.mpi.core.controller.object_store import object_store
-from unidist.core.backends.mpi.core.controller.common import initial_worker_number
+from unidist.core.backends.mpi.core.local_object_store import LocalObjectStore
 
 
 logger = common.get_logger("utils", "utils.log")
@@ -23,7 +22,7 @@ class GarbageCollector:
 
     Parameters
     ----------
-    object_store : unidist.core.backends.mpi.executor.ObjectStore
+    local_store : unidist.core.backends.mpi.core.local_object_store
         Reference to the local object storage.
 
     Notes
@@ -31,17 +30,17 @@ class GarbageCollector:
     Cleanup relies on internal threshold settings.
     """
 
-    def __init__(self, object_store):
+    def __init__(self, local_store):
         # Cleanup frequency settings
         self._cleanup_counter = 1
         self._cleanup_threshold = 5
         self._time_threshold = 1  # seconds
         self._timestamp = 0  # seconds
-        # Cleanup list of DataIDs
+        # Cleanup list of tuple(owner_rank, data_number)
         self._cleanup_list = []
         self._cleanup_list_threshold = 10
         # Reference to the global object store
-        self._object_store = object_store
+        self._local_store = local_store
         # Task submitted counter
         self._task_counter = 0
 
@@ -54,19 +53,15 @@ class GarbageCollector:
         cleanup_list : list
             List of data IDs.
         """
-        logger.debug(
-            "Send cleanup list - {}".format(
-                common.unwrapped_data_ids_list(cleanup_list)
-            )
-        )
+        logger.debug(f"Send cleanup list - {cleanup_list}")
         mpi_state = communication.MPIState.get_instance()
         # Cache serialized list of data IDs
         s_cleanup_list = SimpleDataSerializer().serialize_pickle(cleanup_list)
         async_operations = AsyncOperations.get_instance()
-        for rank_id in range(initial_worker_number, mpi_state.world_size):
-            if rank_id != mpi_state.rank:
+        for rank_id in mpi_state.workers + mpi_state.monitor_processes:
+            if rank_id != mpi_state.global_rank:
                 h_list = communication.isend_serialized_operation(
-                    mpi_state.comm,
+                    mpi_state.global_comm,
                     common.Operation.CLEANUP,
                     s_cleanup_list,
                     rank_id,
@@ -91,8 +86,8 @@ class GarbageCollector:
 
         Parameters
         ----------
-        data_id : unidist.core.backends.mpi.core.common.MasterDataID
-            An ID to data
+        data_id_metadata : tuple
+            Tuple of the owner rank and data number describing a ``MpiDataID``.
         """
         self._cleanup_list.append(data_id)
 
@@ -119,17 +114,20 @@ class GarbageCollector:
                     logger.debug("Cleanup counter {}".format(self._cleanup_counter))
 
                     mpi_state = communication.MPIState.get_instance()
+                    root_monitor = mpi_state.get_monitor_by_worker_rank(
+                        communication.MPIRank.ROOT
+                    )
                     # Compare submitted and executed tasks
                     # We use a blocking send here because we have to wait for
                     # completion of the communication, which is necessary for the pipeline to continue.
-                    communication.mpi_send_object(
-                        mpi_state.comm,
+                    communication.mpi_send_operation(
+                        mpi_state.global_comm,
                         common.Operation.GET_TASK_COUNT,
-                        communication.MPIRank.MONITOR,
+                        root_monitor,
                     )
-                    executed_task_counter = communication.recv_simple_operation(
-                        mpi_state.comm,
-                        communication.MPIRank.MONITOR,
+                    executed_task_counter = communication.mpi_recv_object(
+                        mpi_state.global_comm,
+                        root_monitor,
                     )
 
                     logger.debug(
@@ -139,8 +137,6 @@ class GarbageCollector:
                     )
                     if executed_task_counter == self._task_counter:
                         self._send_cleanup_request(self._cleanup_list)
-                        # Clear the remaining references
-                        self._object_store.clear(self._cleanup_list)
                         self._cleanup_list.clear()
                         self._cleanup_counter += 1
                         self._timestamp = time.perf_counter()
@@ -148,4 +144,4 @@ class GarbageCollector:
                 self._cleanup_counter += 1
 
 
-garbage_collector = GarbageCollector(object_store)
+garbage_collector = GarbageCollector(LocalObjectStore.get_instance())
