@@ -17,16 +17,16 @@ def init_backend():
     -----
     The concrete execution backend can be set via
     `UNIDIST_BACKEND` environment variable or ``Backend`` config value.
-    Ray backend is used by default.
+    MPI backend is used by default.
     """
     backend_name = Backend.get()
 
-    if backend_name == BackendName.RAY:
-        from unidist.core.backends.ray.backend import RayBackend
-        from unidist.core.backends.ray.utils import initialize_ray
+    if backend_name == BackendName.MPI:
+        from unidist.core.backends.mpi.backend import MPIBackend
+        from unidist.core.backends.mpi.utils import initialize_mpi
 
-        initialize_ray()
-        backend_cls = RayBackend()
+        initialize_mpi()
+        backend_cls = MPIBackend()
     elif backend_name == BackendName.DASK:
         import threading
 
@@ -36,12 +36,12 @@ def init_backend():
 
             initialize_dask()
             backend_cls = DaskBackend()
-    elif backend_name == BackendName.MPI:
-        from unidist.core.backends.mpi.backend import MPIBackend
-        from unidist.core.backends.mpi.utils import initialize_mpi
+    elif backend_name == BackendName.RAY:
+        from unidist.core.backends.ray.backend import RayBackend
+        from unidist.core.backends.ray.utils import initialize_ray
 
-        initialize_mpi()
-        backend_cls = MPIBackend()
+        initialize_ray()
+        backend_cls = RayBackend()
     elif backend_name == BackendName.PYMP:
         from unidist.core.backends.pymp.backend import PyMpBackend
         from unidist.core.backends.pymp.utils import (
@@ -75,18 +75,18 @@ def get_backend_proxy():
 
     if backend is None:
         backend_name = Backend.get()
-        if backend_name == BackendName.RAY:
-            from unidist.core.backends.ray.backend import RayBackend
+        if backend_name == BackendName.MPI:
+            from unidist.core.backends.mpi.backend import MPIBackend
 
-            backend_cls = RayBackend()
+            backend_cls = MPIBackend()
         elif backend_name == BackendName.DASK:
             from unidist.core.backends.dask.backend import DaskBackend
 
             backend_cls = DaskBackend()
-        elif backend_name == BackendName.MPI:
-            from unidist.core.backends.mpi.backend import MPIBackend
+        elif backend_name == BackendName.RAY:
+            from unidist.core.backends.ray.backend import RayBackend
 
-            backend_cls = MPIBackend()
+            backend_cls = RayBackend()
         elif backend_name == BackendName.PYMP:
             from unidist.core.backends.pymp.backend import (
                 PyMpBackend,
