@@ -1,4 +1,4 @@
-# Copyright (C) 2021-2022 Modin authors
+# Copyright (C) 2021-2023 Modin authors
 #
 # SPDX-License-Identifier: Apache-2.0
 
@@ -26,7 +26,7 @@ def call_gc_collect():
 
 
 @pytest.mark.skipif(
-    sys.platform == "win32" and Backend.get() == BackendName.MP,
+    sys.platform == "win32" and Backend.get() == BackendName.PYMP,
     reason="Details are in https://github.com/modin-project/unidist/issues/70.",
 )
 @pytest.mark.parametrize("is_default_constructor", [True, False])
@@ -36,7 +36,7 @@ def test_actor_constructor(is_default_constructor):
 
 
 @pytest.mark.skipif(
-    sys.platform == "win32" and Backend.get() == BackendName.MP,
+    sys.platform == "win32" and Backend.get() == BackendName.PYMP,
     reason="Details are in https://github.com/modin-project/unidist/issues/70.",
 )
 def test_chaining():
@@ -46,7 +46,7 @@ def test_chaining():
 
 
 @pytest.mark.skipif(
-    sys.platform == "win32" and Backend.get() == BackendName.MP,
+    sys.platform == "win32" and Backend.get() == BackendName.PYMP,
     reason="Details are in https://github.com/modin-project/unidist/issues/70.",
 )
 def test_num_returns():
@@ -57,11 +57,11 @@ def test_num_returns():
 
 
 @pytest.mark.skipif(
-    Backend.get() == BackendName.MP,
-    reason="`multiprocessing` backend incorrectly frees grabbed actors. Details are in https://github.com/modin-project/unidist/issues/65.",
+    Backend.get() == BackendName.PYMP,
+    reason="`pymp` backend incorrectly frees grabbed actors. Details are in https://github.com/modin-project/unidist/issues/65.",
 )
 @pytest.mark.skipif(
-    sys.platform == "win32" and Backend.get() == BackendName.MP,
+    sys.platform == "win32" and Backend.get() == BackendName.PYMP,
     reason="Details are in https://github.com/modin-project/unidist/issues/70.",
 )
 @pytest.mark.parametrize("is_use_options", [True, False])
@@ -77,8 +77,8 @@ def test_address_space(is_use_options):
 
 
 @pytest.mark.skipif(
-    Backend.get() == BackendName.MP,
-    reason="Proper serialization/deserialization is not implemented yet for multiprocessing",
+    Backend.get() == BackendName.PYMP,
+    reason="Proper serialization/deserialization is not implemented yet for pymp",
 )
 def test_global_capture():
     actor = TestActor.remote(0)
@@ -94,8 +94,8 @@ def test_global_capture():
 
 
 @pytest.mark.skipif(
-    Backend.get() == BackendName.MP,
-    reason="Proper serialization/deserialization is not implemented yet for multiprocessing",
+    Backend.get() == BackendName.PYMP,
+    reason="Proper serialization/deserialization is not implemented yet for pymp",
 )
 def test_direct_capture():
     actor = TestActor.remote(0)
@@ -111,7 +111,7 @@ def test_direct_capture():
 
 
 @pytest.mark.skipif(
-    Backend.get() == BackendName.MP,
+    Backend.get() == BackendName.PYMP,
     reason="Details are in https://github.com/modin-project/unidist/issues/70.",
 )
 def test_return_none():
@@ -120,8 +120,8 @@ def test_return_none():
 
 
 @pytest.mark.skipif(
-    Backend.get() == BackendName.MP,
-    reason="Run of a remote task inside of an actor method is not implemented yet for multiprocessing",
+    Backend.get() == BackendName.PYMP,
+    reason="Run of a remote task inside of an actor method is not implemented yet for pymp",
 )
 @pytest.mark.skipif(
     Backend.get() == BackendName.DASK,
